# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .action_response import ActionResponse
    from .active_sessions_result import ActiveSessionsResult
    from .annotations import Annotations
    from .annotations_audience_item import AnnotationsAudienceItem
    from .audio_content import AudioContent
    from .bash_command_status import BashCommandStatus
    from .blob_resource_contents import BlobResourceContents
    from .browser_info_result import BrowserInfoResult
    from .browser_viewport import BrowserViewport
    from .button import Button
    from .call_tool_result import CallToolResult
    from .call_tool_result_content_item import (
        CallToolResultContentItem,
        CallToolResultContentItem_Audio,
        CallToolResultContentItem_Image,
        CallToolResultContentItem_Resource,
        CallToolResultContentItem_ResourceLink,
        CallToolResultContentItem_Text,
    )
    from .click_action import ClickAction
    from .console_record import ConsoleRecord
    from .double_click_action import DoubleClickAction
    from .drag_to_action import DragToAction
    from .embedded_resource import EmbeddedResource
    from .file_content_encoding import FileContentEncoding
    from .file_find_result import FileFindResult
    from .file_info import FileInfo
    from .file_list_result import FileListResult
    from .file_read_result import FileReadResult
    from .file_replace_result import FileReplaceResult
    from .file_search_result import FileSearchResult
    from .file_upload_result import FileUploadResult
    from .file_write_result import FileWriteResult
    from .hotkey_action import HotkeyAction
    from .http_validation_error import HttpValidationError
    from .image_content import ImageContent
    from .jupyter_execute_response import JupyterExecuteResponse
    from .jupyter_info_response import JupyterInfoResponse
    from .jupyter_output import JupyterOutput
    from .key_down_action import KeyDownAction
    from .key_up_action import KeyUpAction
    from .list_tools_result import ListToolsResult
    from .mouse_down_action import MouseDownAction
    from .mouse_up_action import MouseUpAction
    from .move_to_action import MoveToAction
    from .node_js_execute_response import NodeJsExecuteResponse
    from .node_js_output import NodeJsOutput
    from .node_js_runtime_info import NodeJsRuntimeInfo
    from .ping_body import PingBody
    from .press_action import PressAction
    from .resolution import Resolution
    from .resource import Resource
    from .resource_link import ResourceLink
    from .response import Response
    from .response_active_sessions_result import ResponseActiveSessionsResult
    from .response_browser_info_result import ResponseBrowserInfoResult
    from .response_call_tool_result import ResponseCallToolResult
    from .response_file_find_result import ResponseFileFindResult
    from .response_file_list_result import ResponseFileListResult
    from .response_file_read_result import ResponseFileReadResult
    from .response_file_replace_result import ResponseFileReplaceResult
    from .response_file_search_result import ResponseFileSearchResult
    from .response_file_upload_result import ResponseFileUploadResult
    from .response_file_write_result import ResponseFileWriteResult
    from .response_jupyter_execute_response import ResponseJupyterExecuteResponse
    from .response_jupyter_info_response import ResponseJupyterInfoResponse
    from .response_list_str import ResponseListStr
    from .response_list_tools_result import ResponseListToolsResult
    from .response_node_js_execute_response import ResponseNodeJsExecuteResponse
    from .response_node_js_runtime_info import ResponseNodeJsRuntimeInfo
    from .response_shell_command_result import ResponseShellCommandResult
    from .response_shell_kill_result import ResponseShellKillResult
    from .response_shell_view_result import ResponseShellViewResult
    from .response_shell_wait_result import ResponseShellWaitResult
    from .response_shell_write_result import ResponseShellWriteResult
    from .response_str_replace_editor_result import ResponseStrReplaceEditorResult
    from .right_click_action import RightClickAction
    from .sandbox_response import SandboxResponse
    from .scroll_action import ScrollAction
    from .session_info import SessionInfo
    from .shell_command_result import ShellCommandResult
    from .shell_kill_result import ShellKillResult
    from .shell_view_result import ShellViewResult
    from .shell_wait_result import ShellWaitResult
    from .shell_write_result import ShellWriteResult
    from .str_replace_editor_result import StrReplaceEditorResult
    from .text_content import TextContent
    from .text_resource_contents import TextResourceContents
    from .tool import Tool
    from .tool_annotations import ToolAnnotations
    from .typing_action import TypingAction
    from .validation_error import ValidationError
    from .validation_error_loc_item import ValidationErrorLocItem
_dynamic_imports: typing.Dict[str, str] = {
    "ActionResponse": ".action_response",
    "ActiveSessionsResult": ".active_sessions_result",
    "Annotations": ".annotations",
    "AnnotationsAudienceItem": ".annotations_audience_item",
    "AudioContent": ".audio_content",
    "BashCommandStatus": ".bash_command_status",
    "BlobResourceContents": ".blob_resource_contents",
    "BrowserInfoResult": ".browser_info_result",
    "BrowserViewport": ".browser_viewport",
    "Button": ".button",
    "CallToolResult": ".call_tool_result",
    "CallToolResultContentItem": ".call_tool_result_content_item",
    "CallToolResultContentItem_Audio": ".call_tool_result_content_item",
    "CallToolResultContentItem_Image": ".call_tool_result_content_item",
    "CallToolResultContentItem_Resource": ".call_tool_result_content_item",
    "CallToolResultContentItem_ResourceLink": ".call_tool_result_content_item",
    "CallToolResultContentItem_Text": ".call_tool_result_content_item",
    "ClickAction": ".click_action",
    "ConsoleRecord": ".console_record",
    "DoubleClickAction": ".double_click_action",
    "DragToAction": ".drag_to_action",
    "EmbeddedResource": ".embedded_resource",
    "FileContentEncoding": ".file_content_encoding",
    "FileFindResult": ".file_find_result",
    "FileInfo": ".file_info",
    "FileListResult": ".file_list_result",
    "FileReadResult": ".file_read_result",
    "FileReplaceResult": ".file_replace_result",
    "FileSearchResult": ".file_search_result",
    "FileUploadResult": ".file_upload_result",
    "FileWriteResult": ".file_write_result",
    "HotkeyAction": ".hotkey_action",
    "HttpValidationError": ".http_validation_error",
    "ImageContent": ".image_content",
    "JupyterExecuteResponse": ".jupyter_execute_response",
    "JupyterInfoResponse": ".jupyter_info_response",
    "JupyterOutput": ".jupyter_output",
    "KeyDownAction": ".key_down_action",
    "KeyUpAction": ".key_up_action",
    "ListToolsResult": ".list_tools_result",
    "MouseDownAction": ".mouse_down_action",
    "MouseUpAction": ".mouse_up_action",
    "MoveToAction": ".move_to_action",
    "NodeJsExecuteResponse": ".node_js_execute_response",
    "NodeJsOutput": ".node_js_output",
    "NodeJsRuntimeInfo": ".node_js_runtime_info",
    "PingBody": ".ping_body",
    "PressAction": ".press_action",
    "Resolution": ".resolution",
    "Resource": ".resource",
    "ResourceLink": ".resource_link",
    "Response": ".response",
    "ResponseActiveSessionsResult": ".response_active_sessions_result",
    "ResponseBrowserInfoResult": ".response_browser_info_result",
    "ResponseCallToolResult": ".response_call_tool_result",
    "ResponseFileFindResult": ".response_file_find_result",
    "ResponseFileListResult": ".response_file_list_result",
    "ResponseFileReadResult": ".response_file_read_result",
    "ResponseFileReplaceResult": ".response_file_replace_result",
    "ResponseFileSearchResult": ".response_file_search_result",
    "ResponseFileUploadResult": ".response_file_upload_result",
    "ResponseFileWriteResult": ".response_file_write_result",
    "ResponseJupyterExecuteResponse": ".response_jupyter_execute_response",
    "ResponseJupyterInfoResponse": ".response_jupyter_info_response",
    "ResponseListStr": ".response_list_str",
    "ResponseListToolsResult": ".response_list_tools_result",
    "ResponseNodeJsExecuteResponse": ".response_node_js_execute_response",
    "ResponseNodeJsRuntimeInfo": ".response_node_js_runtime_info",
    "ResponseShellCommandResult": ".response_shell_command_result",
    "ResponseShellKillResult": ".response_shell_kill_result",
    "ResponseShellViewResult": ".response_shell_view_result",
    "ResponseShellWaitResult": ".response_shell_wait_result",
    "ResponseShellWriteResult": ".response_shell_write_result",
    "ResponseStrReplaceEditorResult": ".response_str_replace_editor_result",
    "RightClickAction": ".right_click_action",
    "SandboxResponse": ".sandbox_response",
    "ScrollAction": ".scroll_action",
    "SessionInfo": ".session_info",
    "ShellCommandResult": ".shell_command_result",
    "ShellKillResult": ".shell_kill_result",
    "ShellViewResult": ".shell_view_result",
    "ShellWaitResult": ".shell_wait_result",
    "ShellWriteResult": ".shell_write_result",
    "StrReplaceEditorResult": ".str_replace_editor_result",
    "TextContent": ".text_content",
    "TextResourceContents": ".text_resource_contents",
    "Tool": ".tool",
    "ToolAnnotations": ".tool_annotations",
    "TypingAction": ".typing_action",
    "ValidationError": ".validation_error",
    "ValidationErrorLocItem": ".validation_error_loc_item",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "ActionResponse",
    "ActiveSessionsResult",
    "Annotations",
    "AnnotationsAudienceItem",
    "AudioContent",
    "BashCommandStatus",
    "BlobResourceContents",
    "BrowserInfoResult",
    "BrowserViewport",
    "Button",
    "CallToolResult",
    "CallToolResultContentItem",
    "CallToolResultContentItem_Audio",
    "CallToolResultContentItem_Image",
    "CallToolResultContentItem_Resource",
    "CallToolResultContentItem_ResourceLink",
    "CallToolResultContentItem_Text",
    "ClickAction",
    "ConsoleRecord",
    "DoubleClickAction",
    "DragToAction",
    "EmbeddedResource",
    "FileContentEncoding",
    "FileFindResult",
    "FileInfo",
    "FileListResult",
    "FileReadResult",
    "FileReplaceResult",
    "FileSearchResult",
    "FileUploadResult",
    "FileWriteResult",
    "HotkeyAction",
    "HttpValidationError",
    "ImageContent",
    "JupyterExecuteResponse",
    "JupyterInfoResponse",
    "JupyterOutput",
    "KeyDownAction",
    "KeyUpAction",
    "ListToolsResult",
    "MouseDownAction",
    "MouseUpAction",
    "MoveToAction",
    "NodeJsExecuteResponse",
    "NodeJsOutput",
    "NodeJsRuntimeInfo",
    "PingBody",
    "PressAction",
    "Resolution",
    "Resource",
    "ResourceLink",
    "Response",
    "ResponseActiveSessionsResult",
    "ResponseBrowserInfoResult",
    "ResponseCallToolResult",
    "ResponseFileFindResult",
    "ResponseFileListResult",
    "ResponseFileReadResult",
    "ResponseFileReplaceResult",
    "ResponseFileSearchResult",
    "ResponseFileUploadResult",
    "ResponseFileWriteResult",
    "ResponseJupyterExecuteResponse",
    "ResponseJupyterInfoResponse",
    "ResponseListStr",
    "ResponseListToolsResult",
    "ResponseNodeJsExecuteResponse",
    "ResponseNodeJsRuntimeInfo",
    "ResponseShellCommandResult",
    "ResponseShellKillResult",
    "ResponseShellViewResult",
    "ResponseShellWaitResult",
    "ResponseShellWriteResult",
    "ResponseStrReplaceEditorResult",
    "RightClickAction",
    "SandboxResponse",
    "ScrollAction",
    "SessionInfo",
    "ShellCommandResult",
    "ShellKillResult",
    "ShellViewResult",
    "ShellWaitResult",
    "ShellWriteResult",
    "StrReplaceEditorResult",
    "TextContent",
    "TextResourceContents",
    "Tool",
    "ToolAnnotations",
    "TypingAction",
    "ValidationError",
    "ValidationErrorLocItem",
]
