# This file was auto-generated by Fern from our API Definition.

import typing

BashCommandStatus = typing.Union[
    typing.Literal["running", "completed", "no_change_timeout", "hard_timeout", "terminated"], typing.Any
]
