# This file was auto-generated by Fern from our API Definition.

import typing

from .blob_resource_contents import BlobResourceContents
from .text_resource_contents import TextResourceContents

Resource = typing.Union[TextResourceContents, BlobResourceContents]
