# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .file_search_result import FileSearchResult


class ResponseFileSearchResult(UniversalBaseModel):
    success: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether the operation was successful
    """

    message: typing.Optional[str] = pydantic.Field(default=None)
    """
    Operation result message
    """

    data: typing.Optional[FileSearchResult] = pydantic.Field(default=None)
    """
    Data returned from the operation
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
