# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class FileSearchResult(UniversalBaseModel):
    """
    File content search result
    """

    file: str = pydantic.Field()
    """
    Path of the searched file
    """

    matches: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of matched content
    """

    line_numbers: typing.Optional[typing.List[int]] = pydantic.Field(default=None)
    """
    List of matched line numbers
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
